"""
Whoosh: Alpha Step 1: Create

Create a schema and an index
for a pile of Markdown documents.

Note that if you keep adding
a document to the index, it
creates duplicate records, so
you'll end up with a bunch of 
duplicates in your search results.
"""

import os.path
import glob

# ---------------
# Create schema

# Related:
# Designing a schema
# https://whoosh.readthedocs.io/en/latest/schema.html

from whoosh.fields import Schema, STORED, ID, KEYWORD, TEXT

# Keep the schema as simple as possible for now.
# stored = this field is stored with the document, but not indexed and not searchable
schema = Schema(title=TEXT(stored=True), 
                content=TEXT(stored=True),
                path=ID(stored=True))

# -------------
# Create index

# Related:
# Creating an index object
# https://whoosh.readthedocs.io/en/latest/indexing.html#creating-an-index-object

from whoosh.index import create_in
from whoosh.index import open_dir

# create an index:
if not os.path.exists("index"):
        os.mkdir("index")
        ix = create_in("index", schema)

# now open the index:
ix = open_dir("index")


# -----------------
# Write to index

# Related:
# Indexing documents
# https://whoosh.readthedocs.io/en/latest/indexing.html#indexing-documents

writer = ix.writer()

# NOTE:
# This should UPDATE records,
# otherwise we end up with a
# bunch of duplicate records

globules = glob.glob("fake-docs/**", recursive=True)

for globule in globules:
    if(os.path.isfile(globule)):
        with open(globule,'r') as f:

            filepath, filename = os.path.split(globule)
            basename = os.path.splitext(filename)

            doc_title = basename
            doc_content = f.read()
            doc_path = globule

            writer.add_document(title = doc_title,
                                content = doc_content,
                                path = doc_path)
writer.commit()




