"""
Whoosh: Alpha Step 2: Search

Use the index created in step 1
to search for stuff.
"""

import os.path
import glob

from whoosh.index import create_in
from whoosh.index import open_dir

from whoosh.fields import Schema, STORED, ID, KEYWORD, TEXT

# ---------------
# Search index

# Related:
# How to search
# https://whoosh.readthedocs.io/en/latest/searching.html


# now open the index:
ix = open_dir("index")

searcher = ix.searcher()

with ix.searcher() as searcher:

    from whoosh.query import *

    option = 2

    if option==1:

        # -----------
        # Option 1:
        # 
        # Use the default parser
        # Create a parser that is the default parser
        # 
        from whoosh.qparser import QueryParser
        parser = QueryParser("content", schema=ix.schema)
        parser.parse(u"epoch OR coronation")

    if option==2:

        # -----------
        # Option 2:
        # 
        # Manually construct the search using Term objects and And/Or

        # Search for documents where field "content"
        # matches the term epoch and the term coronation
        myquery = And([
                        Term("content", u"epoch"), 
                        Term("content", "coronation")
        ])

        # perform a search with the query
        results = searcher.search(myquery, limit=20)
        import pdb; pdb.set_trace()
        for result in results:
            print(result)

    if option==3:

        # ----------
        # Option 3:
        # 
        # Let user search across multiple fields,
        # i.e., overload first arg of Term()

        from whoosh.qparser import MultifieldParser
        
        mparser = MultifieldParser(["title", "content"], schema=ix.schema)
        mparser.parse(u"epoch OR coronation")

   

